.. toctree::
   :maxdepth: 1
   :hidden:

   User Guide <user_guide/index>
   Examples <auto_examples/index>
   Reference <reference/index>
   Release Notes <changes>
   Citing <citing>
   Contribute <contributing>

.. include:: intro.rst
